##  Fact Sheet Settings
The following table provides an overview of fact sheet settings, explaining the purpose of each setting and where to configure it. For additional information, refer to the relevant documentation topics.
Setting | Details | Where to Configure | Additional Information
---|---|---|---
Name and description | You can modify the fact sheet names and descriptions, along with their translations into other languages. The fact sheet key, which is a unique fact sheet identifier, can not be modified. To streamline the translation process, use AI capabilities. | On the Fields tab of the fact sheet configuration page, select the fact sheet header, then go to the Translations tab on the right-side panel. |  [Fact Sheet Description](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275955467a441014a5dce078bf2e383c__fact_sheet_description) [AI-Supported Translation](https://help.sap.com/docs/leanix/ea/base-ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758e1767a441014b89cdbb68f4cded0__ai-supported_translation)
Basic parameters | Basic (global) parameters include the fact sheet color, maximum hierarchy level, and the possibility to create fact sheets on the fly. | On the Fields tab of the fact sheet configuration page, select the fact sheet header, then adjust these settings on the Configuration tab on the right-side panel. |  [Fact Sheet Order and Colors](https://help.sap.com/docs/leanix/ea/fact-sheet-order-and-colors?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of standard order and colors of fact sheets in the meta model v4 and learn how to change them.")
Default inventory filters | You can define the default filters to be displayed on the filter panel in the inventory. Users can customize their displayed filters. Once custom filters are set, the default filters configured on the fact sheet no longer apply. | On the Fields tab of the fact sheet configuration page, select the fact sheet header, then go to the Filter tab on the right-side panel. | [Displaying and Hiding Filters](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c8bfc7a441014bb2cc509aac188d0__displaying_and_hiding_filters)
Completion weights | The fact sheet completion score measures how much of the required data has been filled out for a fact sheet. You can define how the completion score is calculated by configuring completion weights. | On the Fields tab of the fact sheet configuration page, select the fact sheet header, then go to the Completion weights tab on the right-side panel. |  [Fact Sheet Completeness](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness?locale=en-US&state=PRODUCTION&version=CLOUD "The fact sheet completion score measures the extent of required data filled out for a fact sheet, ensuring data accuracy and completeness. It is based on assigned weights to fields, subsections, and sections.")
Fields | Fields are specific data points within a fact sheet that store individual pieces of information about the entity it represents. | Go to the Fields tab on the fact sheet configuration page and configure fields in the fact sheet body. |  [Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet fields are designed for storing information on specific data points. You can configure existing fields and create custom ones.")
Relations | Relations represent the connections or relationships between different fact sheets, showing how they interact or relate to each other. | Go to the Fields tab on the fact sheet configuration page and configure relations in the fact sheet body. |  [Fact Sheet Relations](https://help.sap.com/docs/leanix/ea/fact-sheet-relations?locale=en-US&state=PRODUCTION&version=CLOUD "Relations represent connections between different fact sheets. Learn how to configure basic and advanced relations.")
Quality seal | Quality seal is a mechanism to ensure the overall integrity and quality of data on fact sheets. | Go to the Quality Seal tab on the fact sheet configuration page. |  [Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD "Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.")
Permissions | Permissions enable you to control access and edit rights for specific data on fact sheets. You can define permissions for non-admin user roles. | Go to the Permissions tab on the fact sheet configuration page. |  [Fact Sheet Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Configure fact sheet permissions for non-admin user roles.")
Conditional attributes | Conditional attributes allow fields and relations in fact sheets to be visible based on related field values. | Go to the Conditional Attributes tab on the fact sheet configuration page. |  [Conditional Attributes](https://help.sap.com/docs/leanix/ea/conditional-attributes?locale=en-US&state=PRODUCTION&version=CLOUD "Conditional attributes allow fields and relations in fact sheets to be visible based on related field values. Conditional attributes enables tailoring of attributes for subtypes, streamlining subtype management.")


